==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QLinuxFbFunctions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtPlatformHeaders/qlinuxfbfunctions.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLinuxFbFunctions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLinuxFbFunctions")
    QLinuxFbFunctions *_ptr = reinterpret_cast<QLinuxFbFunctions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QLinuxFbFunctions_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QLinuxFbFunctions *__qt_this = new(__qtjambi_ptr) QLinuxFbFunctions();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QLinuxFbFunctions
void __qt_destruct_QLinuxFbFunctions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLinuxFbFunctions")
    reinterpret_cast<QLinuxFbFunctions*>(ptr)->~QLinuxFbFunctions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLinuxFbFunctions::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_initialize_1native__Lio_qt_gui_QLinuxFbFunctions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLinuxFbFunctions_0, sizeof(QLinuxFbFunctions), typeid(QLinuxFbFunctions), false, &deleter_QLinuxFbFunctions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLinuxFbFunctions::loadKeymap(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_loadKeymap__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring filename0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::loadKeymap(QString)")
    QTJAMBI_TRY {
        QString  __qt_filename0 = qtjambi_cast<QString>(__jni_env, filename0);
        QLinuxFbFunctions::loadKeymap(__qt_filename0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLinuxFbFunctions::loadKeymapTypeIdentifier()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_loadKeymapTypeIdentifier__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::loadKeymapTypeIdentifier()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray __qt_return_value = QLinuxFbFunctions::loadKeymapTypeIdentifier();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLinuxFbFunctions::switchLang()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_switchLang__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::switchLang()")
    QTJAMBI_TRY {
        QLinuxFbFunctions::switchLang();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLinuxFbFunctions::switchLangTypeIdentifier()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_switchLangTypeIdentifier__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::switchLangTypeIdentifier()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray __qt_return_value = QLinuxFbFunctions::switchLangTypeIdentifier();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLinuxFbFunctions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLinuxFbFunctions>("QLinuxFbFunctions", "io/qt/gui/QLinuxFbFunctions");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QLinuxFbFunctions, {
        ConstructorInfo(&__qt_construct_QLinuxFbFunctions_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLinuxFbFunctions);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QLinuxFbFunctions_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtPlatformHeaders/qlinuxfbfunctions.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QLinuxFbFunctions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QLinuxFbFunctions")
    QLinuxFbFunctions *_ptr = reinterpret_cast<QLinuxFbFunctions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QLinuxFbFunctions()
void __qt_construct_QLinuxFbFunctions(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QLinuxFbFunctions()")
    Q_UNUSED(__java_arguments)
    QLinuxFbFunctions *__qt_this = new(__qtjambi_ptr) QLinuxFbFunctions();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QLinuxFbFunctions::QLinuxFbFunctions()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_initialize_1native__Lio_qt_gui_QLinuxFbFunctions_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::QLinuxFbFunctions()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QLinuxFbFunctions, sizeof(QLinuxFbFunctions), typeid(QLinuxFbFunctions), false, &deleter_QLinuxFbFunctions, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QLinuxFbFunctions
void __qt_destruct_QLinuxFbFunctions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QLinuxFbFunctions")
    reinterpret_cast<QLinuxFbFunctions*>(ptr)->~QLinuxFbFunctions();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QLinuxFbFunctions::loadKeymap(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_loadKeymap__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring filename0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::loadKeymap(QString)")
    QTJAMBI_TRY {
        QString  __qt_filename0 = qtjambi_cast<QString>(__jni_env, filename0);
        QLinuxFbFunctions::loadKeymap(__qt_filename0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLinuxFbFunctions::loadKeymapTypeIdentifier()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_loadKeymapTypeIdentifier__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::loadKeymapTypeIdentifier()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray __qt_return_value = QLinuxFbFunctions::loadKeymapTypeIdentifier();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QLinuxFbFunctions::switchLang()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_switchLang__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::switchLang()")
    QTJAMBI_TRY {
        QLinuxFbFunctions::switchLang();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QLinuxFbFunctions::switchLangTypeIdentifier()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QLinuxFbFunctions_switchLangTypeIdentifier__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QLinuxFbFunctions::switchLangTypeIdentifier()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray __qt_return_value = QLinuxFbFunctions::switchLangTypeIdentifier();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QLinuxFbFunctions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QLinuxFbFunctions>("QLinuxFbFunctions", "io/qt/gui/QLinuxFbFunctions");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QLinuxFbFunctions, {
        ConstructorInfo(&__qt_construct_QLinuxFbFunctions, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QLinuxFbFunctions);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
